@@ -69,7 +69,7 @@ def wait_and_create_network(host, port, timeout=wait_to_create_timeout):
         sleep(.25)
         ttl += .25
     if ttl == timeout:
-        raise Exception("Sorry, cannot connect to jsbridge extension")
+        raise Exception("Sorry, cannot connect to jsbridge extension, port %s" % port)
     
     back_channel, bridge = create_network(host, port)
     sleep(.5)
@@ -85,11 +85,13 @@ def wait_and_create_network(host, port, timeout=wait_to_create_timeout):
 
 class CLI(mozrunner.CLI):
     """Command line interface."""
+    
+    module = "jsbridge"
 
     parser_options = copy.copy(mozrunner.CLI.parser_options)
     parser_options[('-D', '--debug',)] = dict(dest="debug", 
                                              action="store_true",
-                                             help="Install debugging plugins.", 
+                                             help="Install debugging addons.", 
                                              metavar="JSBRIDGE_DEBUG",
                                              default=False )
     parser_options[('-s', '--shell',)] = dict(dest="shell", 
@@ -103,17 +105,18 @@ class CLI(mozrunner.CLI):
     parser_options[('-P', '--port')] = dict(dest="port", default="24242",
                                             help="TCP port to run jsbridge on.")
     
-    debug_plugins = [os.path.join(parent, 'xpi', 'xush-0.2-fx.xpi')]
-    
+    debug_addons = [os.path.join(parent,'xpi', x) for x
+                     in os.listdir(os.path.join(parent,'xpi'))]
+
     def get_profile(self, *args, **kwargs):
         if self.options.debug:
             kwargs.setdefault('preferences', 
                               {}).update({'extensions.checkCompatibility':False})
-        profile = super(CLI, self).get_profile(*args, **kwargs)
-        profile.install_plugin(extension_path)
+        profile = mozrunner.CLI.get_profile(self, *args, **kwargs)
+        profile.install_addon(extension_path)
         if self.options.debug:
-            for p in self.debug_plugins:
-                profile.install_plugin(p)
+            for addon in self.debug_addons:
+                profile.install_addon(addon)
         return profile
         
     def get_runner(self, *args, **kwargs):
